==> nextcloud-app-spreed-5.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/lt_LT.js <==
OC.L10N.register(
    "spreed",
    {
    "Delete server" : "Ištrinti serverį",
    "Add new server" : "Pridėti naują serverį",
    "Saved" : "Įrašyta",
    "STUN server URL" : "STUN serverio URL",
    "TURN server URL" : "TURN serverio URL",
    "UDP and TCP" : "UDP ir TCP",
    "UDP only" : "Tik UDP",
    "TCP only" : "Tik TCP",
    "TURN server protocols" : "TURN serverio protokolai",
    "New public conversation" : "Naujas viešas pokalbis",
    "New group conversation" : "Naujas grupės pokalbis",
    "New conversation …" : "Naujas pokalbis …",
    "Exit fullscreen (f)" : "Išeiti iš viso ekrano (f)",
    "Fullscreen (f)" : "Visas ekranas (f)",
    "Copy" : "Kopijuoti",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
    "Please enter the password for this call" : "Įveskite šio skambučio slaptažodį",
    "Password required" : "Reikalingas slaptažodis",
    "Password" : "Slaptažodis",
    "Cancel" : "Atsisakyti",
    "Submit" : "Pateikti",
    "Change password" : "Pakeisti slaptažodį",
    "Set password" : "Nustatyti slaptažodį",
    "Conversation name" : "Pokalbio pavadinimas",
    "Rename" : "Pervadinti",
    "Copy link" : "Kopijuoti nuorodą",
    "Conversation with {name}" : "Pokalbis su {name}",
    "Error occurred while setting password" : "Nustatant slaptažodį, atsirado klaidų",
    "Link copied!" : "Nuoroda nukopijuota!",
    "You" : "Jūs",
    "No messages yet, start the conversation!" : "Kol kas žinučių nėra, pradėkite pokalbį!",
    "New message …" : "Nauja žinutė …",
    "Send" : "Siųsti",
    "Guest" : "Svečias",
    "[Unknown user name]" : "[Nežinomas naudotojo vardas]",
    "Today" : "Šiandien",
    "Yesterday" : "Vakar",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error occurred while sending message" : "Siunčiant žinutę, įvyko klaida",
    "Waiting for {participantName} to join the call …" : "Laukiama kol {participantName} prisijungs prie skambučio …",
    "Waiting for others to join the call …" : "Laukiama kol kiti prisijungs prie skambučio …",
    "Share this link to invite others!" : "Bendrinkite šią nuorodą, norėdami pakviesti kitus!",
    "WebRTC is not supported in your browser :-/" : "Jūsų naršyklėje WebRTC nėra palaikoma :-/",
    "Please use a different browser like Firefox or Chrome" : "Naudokite kitą naršyklę, tokią kaip Firefox ar Chrome",
    "Waiting for camera and microphone permissions" : "Laukiama kameros ir mikrofono leidimų",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Norėdami naudoti šią programėlę, suteikite savo naršyklei prieigą naudoti jūsų kamerą ir mikrofoną.",
    "Disable video" : "Išjungti vaizdą",
    "Show your screen" : "Rodyti savo ekraną",
    "Stop screensharing" : "Stabdyti ekrano bendrinimą",
    "Mute audio (m)" : "Nutildyti garsą (m)",
    "Enable video (v)" : "Įjungti vaizdą (v)",
    "Disable video (v)" : "Išjungti vaizdą (v)",
    "Screensharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
    "Screensharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
    "Screensharing options" : "Ekrano bendrinimo parinktys",
    "Sharing your screen only works with Firefox version 52 or newer." : "Ekrano bendrinimas veikia tik naudojant Firefox 52 arba naujesnę versiją.",
    "Screensharing extension is required to share your screen." : "Norint bendrinti ekraną yra reikalingas ekrano bendrinimo plėtinys.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Norėdami bendrinti savo ekraną, naudokite kitą naršyklę, tokią kaip Firefox ar Chrome.",
    "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
    "Enable screensharing" : "Įjungti ekrano bendrinimą",
    "moderator" : "moderatorius",
    "Remove participant" : "Šalinti dalyvį",
    "Add participant …" : "Pridėti dalyvį …",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add to favorites" : "Pridėti į mėgstamus",
    "Delete conversation" : "Ištrinti pokalbį",
    "Close" : "Užverti",
    "Show screen" : "Rodyti ekraną",
    "Enable video" : "Įjungti vaizdą",
    "Access to microphone & camera is only possible with HTTPS" : "Prieiga prie mikrofono ir kameros yra įmanoma tik naudojant HTTPS",
    "Access to microphone & camera was denied" : "Prieiga prie mikrofono ir kameros buvo atmesta",
    "WebRTC is not supported in your browser" : "Jūsų naršyklėje WebRTC nėra palaikoma",
    "Error while accessing microphone & camera" : "Klaida, gaunant prieigą prie mikrofono ir kameros",
    "Guest's screen" : "Svečio ekranas",
    "Your screen" : "Jūsų ekranas",
    "(Duration %s)" : "(Trukmė %s)",
    "_%n guest_::_%n guests_" : ["%n svečias","%n svečiai","%n svečių","%n svečių"],
    "{actor} invited you to {call}" : "{actor} pakvietė jus į {call}",
    "You removed the password" : "Jūs pašalinote slaptažodį",
    "{actor} added {user}" : "{actor} pridėjo naudotoją {user}",
    "You added {user}" : "Jūs pridėjote naudotoją {user}",
    "{actor} removed {user}" : "{actor} pašalino naudotoją {user}",
    "You removed {user}" : "Jūs pašalinote naudotoją {user}",
    "%s (guest)" : "%s (svečias)",
    "_%n other guest_::_%n other guests_" : ["ir dar %n svečias","ir dar %n svečiai","ir dar %n svečių","ir dar %n svečias"],
    ", " : ", ",
    "{user} mentioned you in a private conversation" : "{user} jus paminėjo privačiame pokalbyje",
    "%s invited you to a private conversation" : "%s jus pakvietė į privatų pokalbį",
    "{user} invited you to a private conversation" : "{user} jus pakvietė į privatų pokalbį",
    "%s invited you to a group conversation: %s" : "%s jus pakvietė į grupės pokalbį: %s",
    "{user} invited you to a group conversation: {call}" : "{user} jus pakvietė į grupės pokalbį: {call}",
    "%s invited you to a group conversation" : "%s jus pakvietė į grupės pokalbį",
    "{user} invited you to a group conversation" : "{user} jus pakvietė į grupės pokalbį",
    "{user} wants to talk with you" : "{user} nori su jumis pasikalbėti",
    "Conversation not found" : "Pokalbis nerastas",
    "This call is password-protected" : "Šis skambutis yra apsaugotas slaptažodžiu",
    "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
    "STUN servers" : "STUN serveriai",
    "TURN server" : "TURN serveris",
    "Android app" : "Android programėlė",
    "iOS app" : "iOS programėlė",
    "(group)" : "(grupė)",
    "… %s" : "… %s",
    "%s …" : "%s …",
    "… %s …" : "… %s …",
    "%s mentioned you in a private conversation" : "%s jus paminėjo privačiame pokalbyje",
    "%s mentioned you in a group conversation: %s" : "%s jus paminėjo grupės pokalbyje: %s",
    "{user} mentioned you in a group conversation: {call}" : "{user} jus paminėjo grupės pokalbyje: {call}",
    "%s mentioned you in a group conversation" : "%s jus paminėjo grupės pokalbyje",
    "{user} mentioned you in a group conversation" : "{user} jus paminėjo grupės pokalbyje",
    "You were mentioned in a group conversation by a deleted user: %s" : "Ištrintas naudotojas jus paminėjo grupės pokalbyje: %s",
    "You were mentioned in a group conversation by a deleted user: {call}" : "Ištrintas naudotojas jus paminėjo grupės pokalbyje: {call}",
    "You were mentioned in a group conversation by a deleted user" : "Ištrintas naudotojas jus paminėjo grupės pokalbyje",
    "A guest mentioned you in a group conversation: %s" : "Svečias jus paminėjo grupės pokalbyje: %s",
    "A guest mentioned you in a group conversation: {call}" : "Svečias jus paminėjo grupės pokalbyje: {call}",
    "A guest mentioned you in a group conversation" : "Svečias jus paminėjo grupės pokalbyje"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-app-spreed-5.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/lt_LT.js <==
OC.L10N.register(
    "spreed",
    {
    "Delete server" : "Ištrinti serverį",
    "Add new server" : "Pridėti naują serverį",
    "Saved" : "Įrašyta",
    "STUN server URL" : "STUN serverio URL",
    "TURN server URL" : "TURN serverio URL",
    "UDP and TCP" : "UDP ir TCP",
    "UDP only" : "Tik UDP",
    "TCP only" : "Tik TCP",
    "TURN server protocols" : "TURN serverio protokolai",
    "New public conversation" : "Naujas viešas pokalbis",
    "New group conversation" : "Naujas grupės pokalbis",
    "New conversation …" : "Naujas pokalbis …",
    "Participants" : "Dalyviai",
    "Exit fullscreen (f)" : "Išeiti iš viso ekrano (f)",
    "Fullscreen (f)" : "Visas ekranas (f)",
    "Copy" : "Kopijuoti",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
    "Please enter the password for this call" : "Įveskite šio skambučio slaptažodį",
    "Password required" : "Reikalingas slaptažodis",
    "Password" : "Slaptažodis",
    "Cancel" : "Atsisakyti",
    "Submit" : "Pateikti",
    "Change password" : "Pakeisti slaptažodį",
    "Set password" : "Nustatyti slaptažodį",
    "Conversation name" : "Pokalbio pavadinimas",
    "Rename" : "Pervadinti",
    "Copy link" : "Kopijuoti nuorodą",
    "Conversation with {name}" : "Pokalbis su {name}",
    "Error occurred while setting password" : "Nustatant slaptažodį, atsirado klaidų",
    "Link copied!" : "Nuoroda nukopijuota!",
    "You" : "Jūs",
    "No messages yet, start the conversation!" : "Kol kas žinučių nėra, pradėkite pokalbį!",
    "New message …" : "Nauja žinutė …",
    "Send" : "Siųsti",
    "Guest" : "Svečias",
    "[Unknown user name]" : "[Nežinomas naudotojo vardas]",
    "Today" : "Šiandien",
    "Yesterday" : "Vakar",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The message you are trying to send is too long" : "Žinutė, kurią bandote išsiųsti yra pernelyg ilga",
    "Error occurred while sending message" : "Siunčiant žinutę, įvyko klaida",
    "Waiting for {participantName} to join the call …" : "Laukiama kol {participantName} prisijungs prie skambučio …",
    "Waiting for others to join the call …" : "Laukiama kol kiti prisijungs prie skambučio …",
    "Share this link to invite others!" : "Bendrinkite šią nuorodą, norėdami pakviesti kitus!",
    "WebRTC is not supported in your browser :-/" : "Jūsų naršyklėje WebRTC nėra palaikoma :-/",
    "Please use a different browser like Firefox or Chrome" : "Naudokite kitą naršyklę, tokią kaip Firefox ar Chrome",
    "Waiting for camera and microphone permissions" : "Laukiama kameros ir mikrofono leidimų",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Norėdami naudoti šią programėlę, suteikite savo naršyklei prieigą naudoti jūsų kamerą ir mikrofoną.",
    "Disable video" : "Išjungti vaizdą",
    "Show your screen" : "Rodyti savo ekraną",
    "Stop screensharing" : "Stabdyti ekrano bendrinimą",
    "Mute audio (m)" : "Nutildyti garsą (m)",
    "Enable video (v)" : "Įjungti vaizdą (v)",
    "Disable video (v)" : "Išjungti vaizdą (v)",
    "Screensharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
    "Screensharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
    "Screensharing options" : "Ekrano bendrinimo parinktys",
    "Sharing your screen only works with Firefox version 52 or newer." : "Ekrano bendrinimas veikia tik naudojant Firefox 52 arba naujesnę versiją.",
    "Screensharing extension is required to share your screen." : "Norint bendrinti ekraną yra reikalingas ekrano bendrinimo plėtinys.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Norėdami bendrinti savo ekraną, naudokite kitą naršyklę, tokią kaip Firefox ar Chrome.",
    "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
    "Enable screensharing" : "Įjungti ekrano bendrinimą",
    "moderator" : "moderatorius",
    "Remove participant" : "Šalinti dalyvį",
    "Add participant …" : "Pridėti dalyvį …",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add to favorites" : "Pridėti į mėgstamus",
    "Always notify" : "Visada pranešti",
    "Never notify" : "Niekada nepranešti",
    "Delete conversation" : "Ištrinti pokalbį",
    "Close" : "Užverti",
    "Show screen" : "Rodyti ekraną",
    "Enable video" : "Įjungti vaizdą",
    "Access to microphone & camera is only possible with HTTPS" : "Prieiga prie mikrofono ir kameros yra įmanoma tik naudojant HTTPS",
    "Please move your setup to HTTPS" : "Perkelkite savo sąranką į HTTPS",
    "Access to microphone & camera was denied" : "Prieiga prie mikrofono ir kameros buvo atmesta",
    "WebRTC is not supported in your browser" : "Jūsų naršyklėje WebRTC nėra palaikoma",
    "Error while accessing microphone & camera" : "Klaida, gaunant prieigą prie mikrofono ir kameros",
    "Guest's screen" : "Svečio ekranas",
    "Your screen" : "Jūsų ekranas",
    "(Duration %s)" : "(Trukmė %s)",
    "_%n guest_::_%n guests_" : ["%n svečias","%n svečiai","%n svečių","%n svečių"],
    "{actor} invited you to {call}" : "{actor} pakvietė jus į {call}",
    "{actor} set a password" : "{actor} nustatė slaptažodį",
    "You set a password" : "Jūs nustatėte slaptažodį",
    "You removed the password" : "Jūs pašalinote slaptažodį",
    "{actor} added {user}" : "{actor} pridėjo naudotoją {user}",
    "You added {user}" : "Jūs pridėjote naudotoją {user}",
    "{actor} added you" : "{actor} jus pridėjo",
    "{actor} removed {user}" : "{actor} pašalino naudotoją {user}",
    "You removed {user}" : "Jūs pašalinote naudotoją {user}",
    "{actor} removed you" : "{actor} jus pašalino",
    "%s (guest)" : "%s (svečias)",
    "_%n other guest_::_%n other guests_" : ["ir dar %n svečias","ir dar %n svečiai","ir dar %n svečių","ir dar %n svečias"],
    ", " : ", ",
    "%s invited you to a conversation." : "%s jus pakvietė į pokalbį.",
    "You were invited to a conversation." : "Jūs buvote pakviesti į pokalbį.",
    "{user} mentioned you in a private conversation" : "{user} jus paminėjo privačiame pokalbyje",
    "%s invited you to a private conversation" : "%s jus pakvietė į privatų pokalbį",
    "{user} invited you to a private conversation" : "{user} jus pakvietė į privatų pokalbį",
    "%s invited you to a group conversation: %s" : "%s jus pakvietė į grupės pokalbį: %s",
    "{user} invited you to a group conversation: {call}" : "{user} jus pakvietė į grupės pokalbį: {call}",
    "%s invited you to a group conversation" : "%s jus pakvietė į grupės pokalbį",
    "{user} invited you to a group conversation" : "{user} jus pakvietė į grupės pokalbį",
    "{user} wants to talk with you" : "{user} nori su jumis pasikalbėti",
    "Conversation not found" : "Pokalbis nerastas",
    "This call is password-protected" : "Šis skambutis yra apsaugotas slaptažodžiu",
    "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
    "STUN servers" : "STUN serveriai",
    "TURN server" : "TURN serveris",
    "Android app" : "Android programėlė",
    "iOS app" : "iOS programėlė",
    "(group)" : "(grupė)",
    "… %s" : "… %s",
    "%s …" : "%s …",
    "… %s …" : "… %s …",
    "%s mentioned you in a private conversation" : "%s jus paminėjo privačiame pokalbyje",
    "%s mentioned you in a group conversation: %s" : "%s jus paminėjo grupės pokalbyje: %s",
    "{user} mentioned you in a group conversation: {call}" : "{user} jus paminėjo grupės pokalbyje: {call}",
    "%s mentioned you in a group conversation" : "%s jus paminėjo grupės pokalbyje",
    "{user} mentioned you in a group conversation" : "{user} jus paminėjo grupės pokalbyje",
    "You were mentioned in a group conversation by a deleted user: %s" : "Ištrintas naudotojas jus paminėjo grupės pokalbyje: %s",
    "You were mentioned in a group conversation by a deleted user: {call}" : "Ištrintas naudotojas jus paminėjo grupės pokalbyje: {call}",
    "You were mentioned in a group conversation by a deleted user" : "Ištrintas naudotojas jus paminėjo grupės pokalbyje",
    "A guest mentioned you in a group conversation: %s" : "Svečias jus paminėjo grupės pokalbyje: %s",
    "A guest mentioned you in a group conversation: {call}" : "Svečias jus paminėjo grupės pokalbyje: {call}",
    "A guest mentioned you in a group conversation" : "Svečias jus paminėjo grupės pokalbyje"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
